@@ -10,7 +10,7 @@ def test_undefined(hatch, helpers, temp_dir, config_file):
     config_file.model.template.plugins['default']['tests'] = False
     config_file.save()
 
-    project_name = 'My App'
+    project_name = 'My.App'
 
     with temp_dir.as_cwd():
         result = hatch('new', project_name)
@@ -36,7 +36,7 @@ def test_unknown_type(hatch, helpers, temp_dir, config_file):
     config_file.model.template.plugins['default']['tests'] = False
     config_file.save()
 
-    project_name = 'My App'
+    project_name = 'My.App'
 
     with temp_dir.as_cwd():
         result = hatch('new', project_name)
@@ -68,7 +68,7 @@ def test_new(hatch, helpers, temp_dir, config_file):
     config_file.model.template.plugins['default']['tests'] = False
     config_file.save()
 
-    project_name = 'My App'
+    project_name = 'My.App'
 
     with temp_dir.as_cwd():
         result = hatch('new', project_name)
@@ -90,6 +90,7 @@ def test_new(hatch, helpers, temp_dir, config_file):
     assert result.output == helpers.dedent(
         """
         Creating environment: test
+        Checking dependencies
         """
     )
 
@@ -131,7 +132,7 @@ def test_new_selected_python(hatch, helpers, temp_dir, config_file, python_on_pa
     config_file.model.template.plugins['default']['tests'] = False
     config_file.save()
 
-    project_name = 'My App'
+    project_name = 'My.App'
 
     with temp_dir.as_cwd():
         result = hatch('new', project_name)
@@ -153,6 +154,7 @@ def test_new_selected_python(hatch, helpers, temp_dir, config_file, python_on_pa
     assert result.output == helpers.dedent(
         """
         Creating environment: test
+        Checking dependencies
         """
     )
 
@@ -193,7 +195,7 @@ def test_selected_absolute_directory(hatch, helpers, temp_dir, config_file):
     config_file.model.dirs.env = {'virtual': '$VENVS_DIR'}
     config_file.save()
 
-    project_name = 'My App'
+    project_name = 'My.App'
 
     with temp_dir.as_cwd():
         result = hatch('new', project_name)
@@ -215,6 +217,7 @@ def test_selected_absolute_directory(hatch, helpers, temp_dir, config_file):
     assert result.output == helpers.dedent(
         """
         Creating environment: test
+        Checking dependencies
         """
     )
 
@@ -254,7 +257,7 @@ def test_env_var_absolute_directory(hatch, helpers, temp_dir, config_file):
     config_file.model.dirs.env = {'virtual': '$VENVS_DIR'}
     config_file.save()
 
-    project_name = 'My App'
+    project_name = 'My.App'
 
     with temp_dir.as_cwd():
         result = hatch('new', project_name)
@@ -277,6 +280,7 @@ def test_env_var_absolute_directory(hatch, helpers, temp_dir, config_file):
     assert result.output == helpers.dedent(
         """
         Creating environment: test
+        Checking dependencies
         """
     )
 
@@ -299,7 +303,7 @@ def test_selected_local_directory(hatch, helpers, temp_dir, config_file):
     config_file.model.dirs.env = {'virtual': '$VENVS_DIR'}
     config_file.save()
 
-    project_name = 'My App'
+    project_name = 'My.App'
 
     with temp_dir.as_cwd():
         result = hatch('new', project_name)
@@ -320,6 +324,7 @@ def test_selected_local_directory(hatch, helpers, temp_dir, config_file):
     assert result.output == helpers.dedent(
         """
         Creating environment: test
+        Checking dependencies
         """
     )
 
@@ -360,7 +365,7 @@ def test_env_var_local_directory(hatch, helpers, temp_dir, config_file):
     config_file.model.dirs.env = {'virtual': '$VENVS_DIR'}
     config_file.save()
 
-    project_name = 'My App'
+    project_name = 'My.App'
     env_data_path = temp_dir / '.venvs'
 
     with temp_dir.as_cwd():
@@ -382,6 +387,7 @@ def test_env_var_local_directory(hatch, helpers, temp_dir, config_file):
     assert result.output == helpers.dedent(
         """
         Creating environment: test
+        Checking dependencies
         """
     )
 
@@ -402,7 +408,7 @@ def test_enter_project_directory(hatch, config_file, helpers, temp_dir):
     config_file.model.template.plugins['default']['tests'] = False
     config_file.save()
 
-    project_name = 'My App'
+    project_name = 'My.App'
 
     with temp_dir.as_cwd():
         result = hatch('new', project_name)
@@ -430,6 +436,7 @@ def test_enter_project_directory(hatch, config_file, helpers, temp_dir):
     assert result.output == helpers.dedent(
         """
         Creating environment: test
+        Checking dependencies
         """
     )
 
@@ -459,7 +466,7 @@ def test_already_created(hatch, config_file, helpers, temp_dir):
     config_file.model.template.plugins['default']['tests'] = False
     config_file.save()
 
-    project_name = 'My App'
+    project_name = 'My.App'
 
     with temp_dir.as_cwd():
         result = hatch('new', project_name)
@@ -481,6 +488,7 @@ def test_already_created(hatch, config_file, helpers, temp_dir):
     assert result.output == helpers.dedent(
         """
         Creating environment: test
+        Checking dependencies
         """
     )
 
@@ -520,7 +528,7 @@ def test_default(hatch, config_file, helpers, temp_dir):
     config_file.model.template.plugins['default']['tests'] = False
     config_file.save()
 
-    project_name = 'My App'
+    project_name = 'My.App'
 
     with temp_dir.as_cwd():
         result = hatch('new', project_name)
@@ -541,6 +549,7 @@ def test_default(hatch, config_file, helpers, temp_dir):
     assert result.output == helpers.dedent(
         """
         Creating environment: default
+        Checking dependencies
         """
     )
 
@@ -570,7 +579,7 @@ def test_matrix(hatch, helpers, temp_dir, config_file):
     config_file.model.template.plugins['default']['tests'] = False
     config_file.save()
 
-    project_name = 'My App'
+    project_name = 'My.App'
 
     with temp_dir.as_cwd():
         result = hatch('new', project_name)
@@ -592,7 +601,9 @@ def test_matrix(hatch, helpers, temp_dir, config_file):
     assert result.output == helpers.dedent(
         """
         Creating environment: test.9000
+        Checking dependencies
         Creating environment: test.42
+        Checking dependencies
         """
     )
 
@@ -632,7 +643,7 @@ def test_incompatible_single(hatch, helpers, temp_dir, config_file):
     config_file.model.template.plugins['default']['tests'] = False
     config_file.save()
 
-    project_name = 'My App'
+    project_name = 'My.App'
 
     with temp_dir.as_cwd():
         result = hatch('new', project_name)
@@ -677,7 +688,7 @@ def test_incompatible_matrix_full(hatch, helpers, temp_dir, config_file):
     config_file.model.template.plugins['default']['tests'] = False
     config_file.save()
 
-    project_name = 'My App'
+    project_name = 'My.App'
 
     with temp_dir.as_cwd():
         result = hatch('new', project_name)
@@ -725,7 +736,7 @@ def test_incompatible_matrix_partial(hatch, helpers, temp_dir, config_file):
     config_file.model.template.plugins['default']['tests'] = False
     config_file.save()
 
-    project_name = 'My App'
+    project_name = 'My.App'
 
     with temp_dir.as_cwd():
         result = hatch('new', project_name)
@@ -754,6 +765,7 @@ def test_incompatible_matrix_partial(hatch, helpers, temp_dir, config_file):
     assert result.output == helpers.dedent(
         """
         Creating environment: test.42
+        Checking dependencies
         Skipped 1 incompatible environment:
         test.9000 -> unsupported platform
         """
@@ -800,7 +812,7 @@ def test_install_project_default_dev_mode(
     config_file.model.template.plugins['default']['tests'] = False
     config_file.save()
 
-    project_name = 'My App'
+    project_name = 'My.App'
 
     with temp_dir.as_cwd():
         result = hatch('new', project_name)
@@ -822,6 +834,7 @@ def test_install_project_default_dev_mode(
         """
         Creating environment: test
         Installing project in development mode
+        Checking dependencies
         """
     )
 
@@ -859,7 +872,7 @@ def test_install_project_no_dev_mode(hatch, helpers, temp_dir, platform, config_
     config_file.model.template.plugins['default']['tests'] = False
     config_file.save()
 
-    project_name = 'My App'
+    project_name = 'My.App'
 
     with temp_dir.as_cwd():
         result = hatch('new', project_name)
@@ -882,6 +895,7 @@ def test_install_project_no_dev_mode(hatch, helpers, temp_dir, platform, config_
         """
         Creating environment: test
         Installing project
+        Checking dependencies
         """
     )
 
@@ -919,7 +933,7 @@ def test_pre_install_commands(hatch, helpers, temp_dir, config_file):
     config_file.model.template.plugins['default']['tests'] = False
     config_file.save()
 
-    project_name = 'My App'
+    project_name = 'My.App'
 
     with temp_dir.as_cwd():
         result = hatch('new', project_name)
@@ -950,6 +964,7 @@ def test_pre_install_commands(hatch, helpers, temp_dir, config_file):
         Creating environment: test
         Running pre-installation commands
         Installing project in development mode
+        Checking dependencies
         """
     )
     assert (project_path / 'test.txt').is_file()
@@ -959,7 +974,7 @@ def test_pre_install_commands_error(hatch, helpers, temp_dir, config_file):
     config_file.model.template.plugins['default']['tests'] = False
     config_file.save()
 
-    project_name = 'My App'
+    project_name = 'My.App'
 
     with temp_dir.as_cwd():
         result = hatch('new', project_name)
@@ -996,7 +1011,7 @@ def test_post_install_commands(hatch, helpers, temp_dir, config_file):
     config_file.model.template.plugins['default']['tests'] = False
     config_file.save()
 
-    project_name = 'My App'
+    project_name = 'My.App'
 
     with temp_dir.as_cwd():
         result = hatch('new', project_name)
@@ -1027,6 +1042,7 @@ def test_post_install_commands(hatch, helpers, temp_dir, config_file):
         Creating environment: test
         Installing project in development mode
         Running post-installation commands
+        Checking dependencies
         """
     )
     assert (project_path / 'test.txt').is_file()
@@ -1037,7 +1053,7 @@ def test_post_install_commands_error(hatch, helpers, temp_dir, config_file):
     config_file.model.template.plugins['default']['tests'] = False
     config_file.save()
 
-    project_name = 'My App'
+    project_name = 'My.App'
 
     with temp_dir.as_cwd():
         result = hatch('new', project_name)
@@ -1075,7 +1091,7 @@ def test_sync_dependencies(hatch, helpers, temp_dir, platform, config_file, extr
     config_file.model.template.plugins['default']['tests'] = False
     config_file.save()
 
-    project_name = 'My App'
+    project_name = 'My.App'
 
     with temp_dir.as_cwd():
         result = hatch('new', project_name)
@@ -1107,6 +1123,7 @@ def test_sync_dependencies(hatch, helpers, temp_dir, platform, config_file, extr
         Creating environment: test
         Installing project in development mode
         Running post-installation commands
+        Checking dependencies
         Syncing dependencies
         """
     )
@@ -1147,7 +1164,7 @@ def test_features(hatch, helpers, temp_dir, platform, config_file, extract_insta
     config_file.model.template.plugins['default']['tests'] = False
     config_file.save()
 
-    project_name = 'My App'
+    project_name = 'My.App'
 
     with temp_dir.as_cwd():
         result = hatch('new', project_name)
@@ -1173,6 +1190,7 @@ def test_features(hatch, helpers, temp_dir, platform, config_file, extract_insta
         """
         Creating environment: test
         Installing project in development mode
+        Checking dependencies
         """
     )
 
@@ -1210,7 +1228,7 @@ def test_no_project_file(hatch, helpers, temp_dir, config_file):
     config_file.model.template.plugins['default']['tests'] = False
     config_file.save()
 
-    project_name = 'My App'
+    project_name = 'My.App'
 
     with temp_dir.as_cwd():
         result = hatch('new', project_name)
@@ -1230,6 +1248,7 @@ def test_no_project_file(hatch, helpers, temp_dir, config_file):
     assert result.output == helpers.dedent(
         """
         Creating environment: default
+        Checking dependencies
         """
     )
 
