@@ -8,7 +8,7 @@ def test_unknown_type(hatch, helpers, temp_dir_data, config_file):
     config_file.model.template.plugins['default']['tests'] = False
     config_file.save()
 
-    project_name = 'My App'
+    project_name = 'My.App'
 
     with temp_dir_data.as_cwd():
         result = hatch('new', project_name)
@@ -35,7 +35,7 @@ def test_unknown_type(hatch, helpers, temp_dir_data, config_file):
 
 @pytest.mark.requires_internet
 def test_all(hatch, helpers, temp_dir_data, config_file):
-    project_name = 'My App'
+    project_name = 'My.App'
 
     with temp_dir_data.as_cwd():
         result = hatch('new', project_name)
@@ -80,13 +80,18 @@ def test_all(hatch, helpers, temp_dir_data, config_file):
         result = hatch('env', 'prune')
 
     assert result.exit_code == 0, result.output
-    assert not result.output
+    assert result.output == helpers.dedent(
+        """
+        Removing environment: foo
+        Removing environment: bar
+        """
+    )
 
     assert not storage_path.is_dir()
 
 
 def test_incompatible_ok(hatch, helpers, temp_dir_data, config_file):
-    project_name = 'My App'
+    project_name = 'My.App'
 
     with temp_dir_data.as_cwd():
         result = hatch('new', project_name)
@@ -108,7 +113,7 @@ def test_incompatible_ok(hatch, helpers, temp_dir_data, config_file):
 
 
 def test_active(hatch, temp_dir_data, helpers, config_file):
-    project_name = 'My App'
+    project_name = 'My.App'
 
     with temp_dir_data.as_cwd():
         result = hatch('new', project_name)
